@@ -532,7 +532,8 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         snprintf(buf2, BUFSIZ, "%s %d: eval", runinfo->mSName, runinfo->mSLine);
 
         if(parse(buf, buf2, &sline, block, NULL)) {
-            if(!run(block, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+            sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+            if(!run(block, nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                 err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = rcode;
                 stack_end_stack();
