@@ -157,12 +157,6 @@ static void readline_insert_text(char* cmdline, int cursor_point)
     if(n > strlen(rl_line_buffer)) n = strlen(rl_line_buffer);
 
     rl_point = n;
-
-#if defined(__FREEBSD__)
-//extern int rl_reset_terminal PARAMS((const char *));
-    mclear_immediately();
-    rl_forced_update_display();
-#endif
 }
 
 static char* gCmdLine;
