@@ -269,7 +269,6 @@ static BOOL read_one_argument(char** p, sBuf* buf, char* sname, int* sline, BOOL
             if(**p == '\'') {
                 (*p)++;
                 buf->mNullString = TRUE;
-                break;
             }
             else {
                 squote = !squote;
@@ -281,7 +280,6 @@ static BOOL read_one_argument(char** p, sBuf* buf, char* sname, int* sline, BOOL
             if(**p == '"') {
                 (*p)++;
                 buf->mNullString = TRUE;
-                break;
             }
             else {
                 dquote = !dquote;
@@ -957,7 +955,7 @@ static BOOL read_statment(char**p, sStatment* statment, sObject* block, char* sn
         SBLOCK(block).mCompletionFlags |= COMPLETION_FLAGS_STATMENT_HEAD;
     }
 
-    /// a global pipe ///
+    /// a global pipe in ///
     if(**p == '|' && *(*p+1) == '>') {
         (*p)+=2;
 
@@ -1031,12 +1029,19 @@ static BOOL read_statment(char**p, sStatment* statment, sObject* block, char* sn
         }
     }
 
-    /// global pipe
+    /// global pipe out
     if(**p == '|' && *(*p+1) == '>') {
         (*p)+=2;
-        skip_spaces(p);
 
-        statment->mFlags |= STATMENT_GLOBALPIPEOUT;
+        if(**p == '>') {
+            (*p)++;
+            statment->mFlags |= STATMENT_GLOBALPIPEAPPEND;
+        }
+        else {
+            statment->mFlags |= STATMENT_GLOBALPIPEOUT;
+        }
+
+        skip_spaces(p);
     }
 
     /// the termination of a statment
