@@ -158,6 +158,7 @@ struct sStatment;
 #define STATMENT_BACKGROUND 0x020000
 #define STATMENT_GLOBALPIPEIN 0x040000
 #define STATMENT_GLOBALPIPEOUT 0x080000
+#define STATMENT_GLOBALPIPEAPPEND 0x1000000
 #define STATMENT_CONTEXTPIPE 0x100000
 #define STATMENT_NORMAL 0x200000
 #define STATMENT_OROR 0x400000
@@ -492,6 +493,8 @@ typedef BOOL (*fInternalCommand)(sObject*, sObject*, sRunInfo*);
 extern fInternalCommand kInternalCommands[kInnerCommand];
 extern char * gCommandKindStrs[kCommandMax];
 
+extern sObject* gObjectsInPipe;
+
 BOOL xyzsh_rehash(char* sname, int sline);
 
 #if defined(HAVE_MIGEMO_H)
@@ -792,7 +795,6 @@ int get_onig_regex(regex_t** reg, sCommand* command, char* regex);
 extern sObject* gPrompt;
 
 extern sObject* gGlobalPipe;
-extern sObject* gPipes;
 
 int readline_signal();
 void clear_matching_info_variable();
@@ -816,8 +818,6 @@ void readline_write_history();
 void readline_read_history();
 void xyzsh_read_rc_core(char* path);
 
-#define XYZSH_OBJECTS_IN_PIPE_MAX 128
-
 extern sObject* gStackFrames;
 
 #if defined(HAVE_MIGEMO_H)
@@ -825,5 +825,7 @@ void migemo_init();
 void migemo_final();
 #endif
 
+#define XYZSH_OBJECTS_IN_PIPE_MAX 128
+
 #endif
 
